package ArrayListPlay;

// Date - simple date class!
// David, 21/11/2012
//
// Note:	- immutable
//			- complete the compareTo method
//			- do other versions using "String date" & "long days" for properties
//			  then demostrate they can be used by other classes without changing them.
//
// Mod:	 - updated equals method to standard form for indexOf & contains
// 		 - note compareTo requires similar changes to its parameter,
//		   but the class must also be "public class implements Comparable"
//		   for Collections.sort( list) to work properly!

public class Date
{
	// properties
	private int	day;
	private int	month;
	private int	year;

	// constructors

	// default to today's date
	public Date()
	{
		// fix for initial demo!
//		day = 21;
//		month = 11;
//		year = 2012;

		// using deprecated API
//		java.util.Date tmp;
//		tmp = new java.util.Date();
//		day = tmp.getDate();
//		month = tmp.getMonth() + 1;		// Java month is 0..11
//		year = tmp.getYear() + 1900;	// year is relative to 1900

		// using current API
		java.util.Calendar tmp;
		tmp = java.util.Calendar.getInstance();
		day = tmp.get( java.util.Calendar.DATE );
		month = tmp.get( java.util.Calendar.MONTH ) + 1;	// Java month is 0..11
		year = tmp.get( java.util.Calendar.YEAR );
	}

	public Date( int day, int month, int year)
	{
		this.day = day;
		this.month = month;
		this.year = year;
	}

	// copy constructor
	public Date( Date date)
	{
		day = date.day;
		month = date.month;
	}

	// methods
	public int getDay()
	{
		return day;
	}

	public int getMonth()
	{
		return month;
	}

	public int getYear()
	{
		return year;
	}

	// my clone method; not part of Java's framework!
//	public Date clone()
//	{
//		return new Date( day, month, year);
//	}

	public int getAge()
	{
		int	age;

		Date	today;
		today = new Date();

		age = today.year - this.year;
		if ( today.month < this.month)
			age--;
		if ( today.month == this.month
			 && today.day < this.day )
		age--;
		return age;
	}

	public boolean equals( Date otherDate)
	{
		return day == otherDate.day
			   && month == otherDate.month
			   && year == otherDate.year;
	}

	// revised equals method as required for indexOf in ArrayList
	// typecast o to Date and call original equals method
	// or just modify original the same way.
	public boolean equals( Object o)
	{
		// more bulletproofing...
		if ( o == null)
			return false;
		if ( this.getClass() != o.getClass() )
			return false;

		return equals( (Date) o);
	}

	public int compareTo( Date otherDate)
	{
		return 0;	// todo
	}

	public String toString()
	{
		return day + "/" + month + "/" + year;
	}

}